@@ -1,10 +1,10 @@
-# @(#)$Ident: Programs.pm 2013-10-03 01:47 pjf ;
+# @(#)$Ident: Programs.pm 2013-11-21 23:55 pjf ;
 
 package Class::Usul::Programs;
 
 use attributes ();
 use namespace::sweep;
-use version; our $VERSION = qv( sprintf '0.31.%d', q$Rev: 1 $ =~ /\d+/gmx );
+use version; our $VERSION = qv( sprintf '0.32.%d', q$Rev: 1 $ =~ /\d+/gmx );
 
 use Class::Inspector;
 use Class::Usul::Constants;
@@ -32,7 +32,6 @@ use Text::Autoformat;
 use Try::Tiny;
 
 extends q(Class::Usul);
-with    q(Class::Usul::TraitFor::LoadingClasses);
 with    q(Class::Usul::TraitFor::Prompting);
 
 my $EXTNS = [ keys %{ Class::Usul::File->extensions } ];
@@ -80,7 +79,7 @@ option 'noask'        => is => 'ro',   isa => Bool, default => FALSE,
 
 option 'options'      => is => 'ro',   isa => HashRef, format => 's%',
    documentation      =>
-      'Zero, one or more key/value pairs available to the method call',
+      'Zero, one or more key=value pairs available to the method call',
    default            => sub { {} }, short => 'o';
 
 option 'quiet'        => is => 'ro',   isa => Bool, default => FALSE,
@@ -122,6 +121,9 @@ has '_quiet_flag' => is => 'rw',   isa => Bool,
    default        => sub { $_[ 0 ]->quiet_flag },
    init_arg       => 'quiet', lazy => TRUE, writer => '_set__quiet_flag';
 
+has '_run_method' => is => 'lazy', isa => SimpleStr, init_arg => undef,
+   reader         => 'run_method';
+
 # Construction
 around 'BUILDARGS' => sub {
    my ($orig, $self, @args) = @_; my $attr = $orig->( $self, @args );
@@ -147,12 +149,39 @@ sub BUILD {
    return;
 }
 
+sub _build__os {
+   my $self = shift;
+   my $file = 'os_'.$Config{osname}.$self->config->extension;
+   my $path = $self->config->ctrldir->catfile( $file );
+
+   $path->exists or return {};
+
+   my $cfg  = $self->file->data_load( paths => [ $path ] );
+
+   return $cfg->{os} || {};
+}
+
+sub _build__run_method {
+   my $self = shift; my $method = $self->method;
+
+   unless ($method) {
+      if ($method = $self->extra_argv( 0 ) and $self->can_call( $method )) {
+         $method = $self->next_argv;
+      }
+      else { $method = NUL }
+   }
+
+   $method ||= 'run_chain';
+  ($method eq 'help' or $method eq 'run_chain') and $self->quiet( TRUE );
+
+   return $self->method( $method );
+}
+
 # Public methods
 sub add_leader {
    my ($self, $text, $args) = @_; $text or return NUL; $args ||= {};
 
-   my $leader = exists $args->{no_lead}
-              ? NUL : (ucfirst $self->config->name).BRK;
+   my $leader = $args->{no_lead} ? NUL : (ucfirst $self->config->name).BRK;
 
    if ($args->{fill}) {
       my $width = $args->{width} || WIDTH;
@@ -187,7 +216,7 @@ sub error {
 
    $self->log->error( $_ ) for (split m{ \n }mx, "${text}");
 
-   emit_to( \*STDERR, $self->add_leader( $text, $args )."\n" );
+   emit_to \*STDERR, $self->add_leader( $text, $args )."\n";
    $self->debug and __output_stacktrace( $err, $self->verbose );
    return;
 }
@@ -201,7 +230,7 @@ sub fatal {
 
    $self->log->alert( $_ ) for (split m{ \n }mx, $text.$posn);
 
-   emit_to( \*STDERR, $self->add_leader( $text, $args ).$posn."\n" );
+   emit_to \*STDERR, $self->add_leader( $text, $args ).$posn."\n";
    __output_stacktrace( $err, $self->verbose );
    exit FAILED;
 }
@@ -223,7 +252,9 @@ sub help : method {
 sub info {
    my ($self, $text, $args) = @_;
 
-   $text = $self->loc( $text || '[no message]', $args->{args} || [] );
+   my $opts = { params => $args->{args} || [], quote_bind_values => FALSE, };
+
+   $text = $self->loc( $text || '[no message]', $opts );
 
    $self->log->info( $_ ) for (split m{ [\n] }mx, $text);
 
@@ -274,16 +305,15 @@ sub loc {
    my $args = (is_hashref $car) ? { %{ $car } }
             : { params => (is_arrayref $car) ? $car : [ @args ] };
 
-   $args->{domain_names} ||= [ DEFAULT_L10N_DOMAIN, $self->config->name ];
-   $args->{locale      } ||= $self->locale;
+   $args->{domain_names     } //= [ DEFAULT_L10N_DOMAIN, $self->config->name ];
+   $args->{locale           } //= $self->locale;
+   $args->{quote_bind_values} //= TRUE;
 
    return $self->localize( $key, $args );
 }
 
 sub output {
-   my ($self, $text, $args) = @_; $args ||= {};
-
-   $self->quiet and return; $args->{cl} and emit;
+   my ($self, $text, $args) = @_; $args ||= {}; $args->{cl} and emit;
 
    $text = $self->loc( $text || '[no message]', $args->{args} || [] );
 
@@ -301,12 +331,12 @@ sub quiet {
 }
 
 sub run {
-   my $self  = shift; my $method = $self->_get_run_method; my $rv;
+   my $self  = shift; my $method = $self->run_method; my $rv;
 
    my $text  = 'Started by '.logname.' Version '.($self->VERSION || '?').SPC;
       $text .= 'Pid '.(abs $PID);
 
-   $self->output( $text ); umask $self->mode;
+   $self->quiet or $self->output( $text ); umask $self->mode;
 
    if ($method eq 'run_chain' or $self->can_call( $method )) {
       my $params = exists $self->params->{ $method }
@@ -325,7 +355,7 @@ sub run {
    }
 
    if (defined $rv and $rv == OK) {
-      $self->output( 'Finished in '.elapsed.' seconds' );
+      $self->quiet or $self->output( 'Finished in '.elapsed.' seconds' );
    }
    elsif (defined $rv and $rv > OK) { $self->output( "Terminated code ${rv}" ) }
    else {
@@ -368,18 +398,6 @@ sub _apply_stdio_encoding {
    return;
 }
 
-sub _build__os {
-   my $self = shift;
-   my $file = 'os_'.$Config{osname}.$self->config->extension;
-   my $path = $self->config->ctrldir->catfile( $file );
-
-   $path->exists or return {};
-
-   my $cfg  = $self->file->data_load( paths => [ $path ] );
-
-   return $cfg->{os} || {};
-}
-
 sub _catch_run_exception {
    my ($self, $method, $error) = @_; my $e;
 
@@ -401,7 +419,7 @@ sub _dont_ask {
 }
 
 sub _exit_usage {
-   exit $_[ 0 ]->_output_usage( $_[ 1 ] );
+   $_[ 0 ]->quiet( TRUE ); exit $_[ 0 ]->_output_usage( $_[ 1 ] );
 }
 
 sub _exit_version {
@@ -431,21 +449,6 @@ sub _get_debug_option {
    return $self->yorn( 'Do you want debugging turned on', FALSE, TRUE );
 }
 
-sub _get_run_method {
-   my $self = shift; my $method = $self->method;
-
-   unless ($method) {
-      if ($method = $self->extra_argv( 0 ) and $self->can_call( $method )) {
-         $method = $self->next_argv;
-      }
-      else { $method = NUL }
-   }
-
-   $method ||= 'run_chain'; $method eq 'run_chain' and $self->quiet( TRUE );
-
-   return $self->method( $method );
-}
-
 sub _man_page_from {
    my ($self, $src) = @_; my $cfg = $self->config;
 
@@ -476,9 +479,7 @@ sub _output_usage {
                    -verbose => $verbose } ); # Never returns
    }
 
-   my $usage = ucfirst $self->options_usage;
-
-   warn $usage ? $usage : "Did we forget new_with_options?\n";
+   emit_to \*STDERR, $self->options_usage;
    return FAILED;
 }
 
@@ -523,9 +524,9 @@ sub __output_stacktrace {
    my ($e, $verbose) = @_; ($e and blessed $e) or return; $verbose //= 0;
 
    $verbose > 0 and $e->can( 'trace' )
-      and return emit_to( \*STDERR, NUL.$e->trace );
+      and return emit_to \*STDERR, NUL.$e->trace;
 
-   $e->can( 'stacktrace' ) and emit_to( \*STDERR, NUL.$e->stacktrace );
+   $e->can( 'stacktrace' ) and emit_to \*STDERR, NUL.$e->stacktrace;
 
    return;
 }
@@ -542,7 +543,7 @@ Class::Usul::Programs - Provide support for command line programs
 
 =head1 Version
 
-This document describes version v0.31.$Rev: 1 $ of L<Class::Usul::Programs>
+This document describes version v0.32.$Rev: 1 $ of L<Class::Usul::Programs>
 
 =head1 Synopsis
 
@@ -816,8 +817,6 @@ Turning debug on produces some more output
 
 =item L<Class::Usul::File>
 
-=item L<Class::Usul::TraitFor::LoadingClasses>
-
 =item L<Class::Usul::TraitFor::UntaintedGetopts>
 
 =item L<Encode>
